@@ -84,7 +84,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
